@@ -2,7 +2,8 @@ package Net::Whois::Object::AsSet;
 
 use base qw/Net::Whois::Object/;
 
-# From ripe-223 
+# http://www.ripe.net/data-tools/support/documentation/update-ref-manual#section-8
+# http://www.apnic.net/apnic-info/whois_search/using-whois/guide/as-set
 #
 # as-set:       [mandatory]  [single]     [primary/look-up key]
 # descr:        [mandatory]  [multiple]   [ ]
@@ -22,11 +23,8 @@ Net::Whois::Object::AsSet - an object representation of a RPSL AsSet block
 
 =head1 DESCRIPTION
 
-An as-set object defines a set of aut-num objects. The attributes of
-the as-set class are shown in Figure 1.2.2.  The "as-set:" attribute
-defines the name of the set. It is an RPSL name that starts with
-"as-". The "members:" attribute lists the members of the set.  The
-"members:" attribute is a list of AS numbers, or other as-set names.
+An as-set object defines a set of aut-num objects. 
+It defines a group of Autonomous Systems with the same routing policies.
 
 =head1 METHODS
 
@@ -53,10 +51,17 @@ sub new {
 Accessor to the as_set attribute.
 Accepts an optional as_set, always return the current as_set value.
 
+The as_set attribute defines the name of the set. It is an RPSL name that
+starts with "as-" or as_set names and AS numbers separated by colon (':').
+The later form is called Hierarchical form, the former non-hierarchical.
+There must be at least one set-name within the hierarchical form that starts 
+with 'as-'.
+
 =cut
 
 sub as_set {
     my ( $self, $as_set ) = @_;
+
     $self->{as_set} = $as_set if defined $as_set;
     return $self->{as_set};
 }
@@ -67,6 +72,8 @@ Accessor to the descr attribute.
 Accepts an optional descr to be added to the descr array, 
 always return the current descr array.
 
+A short description related to the object's purpose.
+
 =cut
 
 sub descr {
@@ -81,6 +88,9 @@ Accessor to the members attribute.
 Accepts an optional member to be added to the members array,
 always return the current 'members' array.
 
+The members attribute lists the members of the set. It can be either a list
+of AS Numbers, or other as-set names.
+
 =cut
 
 sub members {
@@ -95,10 +105,22 @@ Accessor to the mbrs_by_ref attribute.
 Accepts an optional mbr to be added to the mbrs_by_ref array,
 always return the current mbrs_by_ref array.
 
+The identifier of a registered 'mntner' object that can be used to add members
+to the as-set indirectly.
+
+The mbrs_by_ref attribute can be used in all "set" objects; it allows
+indirect population of a set. If this attribute is used, the set also includes
+objects of the corresponding type (aut-num objects for as-set, for example)
+that are protected by one of these maintainers and whose "member-of:"
+attributes refer to the name of the set. If the value of a mbrs_by_ref
+attribute is ANY, any object of the corresponding type referring to the set is
+a member of the set. If the mbrs_by_ref attribute is missing, the set is
+defined explicitly by the members attribute.
+
 =cut
 
 sub mbrs_by_ref {
-    my ( $self, $mbr) = @_;
+    my ( $self, $mbr ) = @_;
     push @{ $self->{mbrs_by_ref} }, $mbr if defined $mbr;
     return \@{ $self->{mbrs_by_ref} };
 }
@@ -109,6 +131,9 @@ Accessor to the remarks attribute.
 Accepts an optional remark to be added to the remarks array,
 always return the current remarks array.
 
+Information about the object that cannot be stated in other attributes.
+May include a URL or email address.
+
 =cut
 
 sub remarks {
@@ -123,6 +148,14 @@ Accessor to the tech_c attribute.
 Accepts an optional tech_c to be added to the tech_c array,
 always return the current tech_c array.
 
+The NIC-handle of a technical contact 'person' or 'role' object.  As more than
+one person often fulfills a role function, there may be more than one tech-c
+listed.
+
+A technical contact (tech-c) must be a person responsible for the
+day-to-day operation of the network, but does not need to be
+physically located at the site of the network.
+
 =cut
 
 sub tech_c {
@@ -137,6 +170,12 @@ Accessor to the admin_c attribute.
 Accepts an optional admin_c to be added to the admin_c array,
 always return the current admin_c array.
 
+The NIC-handle of an on-site contact 'person' object. As more than one person
+often fulfills a role function, there may be more than one admin-c listed.
+
+An administrative contact (admin-c) must be someone who is physically
+located at the site of the network.
+
 =cut
 
 sub admin_c {
@@ -151,6 +190,9 @@ Accessor to the notify attribute.
 Accepts an optional notify value to be added to the notify array,
 always return the current notify array.
 
+The email address to which notifications of changes to this object will be
+sent.
+
 =cut
 
 sub notify {
@@ -165,6 +207,13 @@ Accessor to the mnt_by attribute.
 Accepts an optional mnt to be added to the mnt_by array,
 always return the current mnt_by array.
 
+Lists a registered 'mntner' used to authorize and authenticate changes to this
+object.
+
+When your database details are protected by a 'mntner' object, then
+only persons with access to the security information of that 'mntner'
+object will be able to change details.
+
 =cut
 
 sub mnt_by {
@@ -179,6 +228,15 @@ Accessor to the changed attribute.
 Accepts an optional changed value to be added to the changed array,
 always return the current changed array.
 
+The email address of who last updated the database object and the date it
+occurred.
+
+Every time a change is made to a database object, this attribute will show
+the email address of the person who made those changes.
+Please use the address format specified in RFC 822 - Standard for
+the Format of ARPA Internet Text Message and provide the date
+format using one of the following two formats: YYYYMMDD or YYMMDD.
+
 =cut
 
 sub changed {
@@ -192,6 +250,8 @@ sub changed {
 Accessor to the source attribute.
 Accepts an optional source, always return the current source.
 
+The database where the object is registered.
+
 =cut
 
 sub source {
