@@ -2,20 +2,22 @@ package Net::Whois::Object::AutNum;
 
 use base qw/Net::Whois::Object/;
 
-# From ripe-223 
+# http://www.ripe.net/data-tools/support/documentation/update-ref-manual#section-9
+# http://www.apnic.net/apnic-info/whois_search/using-whois/guide/aut-num
 #
 # aut-num:       [mandatory]  [single]     [primary/look-up key]
 # as-name:       [mandatory]  [single]     [ ]
 # descr:         [mandatory]  [multiple]   [ ]
 # member-of:     [optional]   [multiple]   [inverse key]
 # import:        [optional]   [multiple]   [ ]
+# mp-import:     [optional]   [multiple]   [ ]
 # export:        [optional]   [multiple]   [ ]
+# mp-export:     [optional]   [multiple]   [ ]
 # default:       [optional]   [multiple]   [ ]
+# mp-default:    [optional]   [multiple]   [ ]
 # remarks:       [optional]   [multiple]   [ ]
 # admin-c:       [mandatory]  [multiple]   [inverse key]
 # tech-c:        [mandatory]  [multiple]   [inverse key]
-# cross-mnt:     [optional]   [multiple]   [inverse key]
-# cross-nfy:     [optional]   [multiple]   [inverse key]
 # notify:        [optional]   [multiple]   [inverse key]
 # mnt-lower:     [optional]   [multiple]   [inverse key]
 # mnt-routes:    [optional]   [multiple]   [inverse key]
@@ -23,9 +25,6 @@ use base qw/Net::Whois::Object/;
 # changed:       [mandatory]  [multiple]   [ ]
 # source:        [mandatory]  [single]     [ ]
 
-# Found into the Wild
-# mp-import
-# mp-export
 
 =head1 NAME
 
@@ -33,17 +32,12 @@ Net::Whois::Object::AutNum - an object representation of a RPSL AutNum block
 
 =head1 DESCRIPTION
 
-An object of the aut-num class is a database representation of an
-Autonomous System (AS), which is a group of IP networks operated by
-one or more network operators that has a single and clearly defined
-external routing policy.</SPAN>
-Objects of this class are used to
-specify routing policies. The attributes of the aut-num class are
-shown in Figure 1.2.3. The value of the "aut-num:" attribute is the AS
-number of the AS described by this object. The "as-name:" attribute is
-a symbolic name (in RPSL name syntax) of the AS. The import, export
-and default routing policies of the AS are specified using the
-"import:", "export:" and "default:" attributes, respectively.
+Autonomous System numbers ('aut-num' objects) are globally unique identifiers
+for Autonomous Systems.
+
+The aut-num object specifies routing policies. It refers to a group of IP
+networks that have a single and clearly defined external routing policy,
+operated by one or more network operators – an Autonomous System (AS).
 
 =head1 METHODS
 
@@ -70,10 +64,23 @@ sub new {
 Accessor to the aut_num attribute.
 Accepts an optional aut_num, always return the current aut_num array.
 
+The value of the aut_num attribute is the AS Number of the Autonomous
+System that this object describes and takes the form of ASn where n is 
+a 32 bit number..
+
+Leading zeroes (AS0352) are not allowed and will be removed (AS352) by the
+database software.
+
 =cut
 
 sub aut_num {
     my ( $self, $aut_num ) = @_;
+
+    if ( $aut_num and $aut_num !~ /^AS\d+/ ) {
+        warn "Illegal aut-num ($aut_num) : should be ASn, n being a 32 bit
+        number with no leading 0";
+    }
+
     $self->{aut_num} = $aut_num if defined $aut_num;
     return $self->{aut_num};
 }
@@ -83,6 +90,8 @@ sub aut_num {
 Accessor to the as_name attribute.
 Accepts an optional as_name, always return the current as_name array.
 
+The as-name attribute is a symbolic name of the AS.
+
 =cut
 
 sub as_name {
@@ -110,6 +119,18 @@ Accessor to the member_of attribute.
 Accepts an optional member_of value to be added to the member_of array,
 always return the current member_of array.
 
+The member_of attribute value identifies a set object that this object
+wants to be a member of. This claim, however, should be acknowledged by a
+respective mbrs_by_ref attribute in the referenced object.
+
+An aut-num may be useful to include in an 'as-set' if your network maintains a
+number of Autonomous Systems or wishes to include its routes in an upstream
+provider's routing information.
+
+To be included in an 'as-set', the 'as-set' object must:
+include the keyword "ANY" or the AS number's mbrs_by_ref attribute
+and/or list the AS number in the members attribute
+
 =cut
 
 sub member_of {
@@ -124,6 +145,8 @@ Accessor to the import attribute.
 Accepts an optional import line to be added to the import array,
 always return the current import array.
 
+The inbound IPv4 routing policy of the AS.
+
 =cut
 
 sub import {
@@ -132,12 +155,30 @@ sub import {
     return \@{ $self->{import} };
 }
 
+=head2 B<mp_import( [$import] )>
+
+Accessor to the mp_import attribute.
+Accepts an optional mp_import line to be added to the import array,
+always return the current mp_import array.
+
+The inbound IPv6 routing policy of the AS.
+
+=cut
+
+sub mp_import {
+    my ( $self, $mp_import ) = @_;
+    push @{ $self->{mp_import} }, $import if defined $import;
+    return \@{ $self->{mp_import} };
+}
+
 =head2 B<export( [$export] )>
 
 Accessor to the export attribute.
 Accepts an optional export line to be added to the export array,
 always return the current export array.
 
+The outbound routing policy of the AS.
+
 =cut
 
 sub export {
@@ -146,12 +187,31 @@ sub export {
     return \@{ $self->{export} };
 }
 
+=head2 B<mp_export( [$mp_export] )>
+
+Accessor to the mp_export attribute.
+Accepts an optional mp_export line to be added to the mp_export array,
+always return the current mp_export array.
+
+The outbound IPv6 routing policy of the AS.
+
+=cut
+
+sub mp_export {
+    my ( $self, $mp_export ) = @_;
+    push @{ $self->{mp_export} }, $mp_export if defined $mp_export;
+    return \@{ $self->{mp_export} };
+}
+
 =head2 B<default( [$default] )>
 
 Accessor to the default attribute.
 Accepts an optional default value to be added to the default array,
 always return the current default array.
 
+The peer network the AS will use for as a default, that is, when the AS has no
+more-specific information on where to send the traffic.
+
 =cut
 
 sub default {
@@ -160,12 +220,33 @@ sub default {
     return \@{ $self->{default} };
 }
 
+=head2 B<mp_default( [$mp_default] )>
+
+Accessor to the mp_default attribute.
+Accepts an optional mp_default line to be added to the mp_default array,
+always return the current mp_default array.
+
+This attribute performs the same function as the 'default' attribute above.
+The difference is that mp-default allows both IPv4 and IPv6 addresses to be
+specified.
+
+=cut
+
+sub mp_default {
+    my ( $self, $mp_default ) = @_;
+    push @{ $self->{mp_default} }, $mp_default if defined $mp_default;
+    return \@{ $self->{mp_default} };
+}
+
 =head2 B<remarks( [$remark] )>
 
 Accessor to the remarks attribute.
 Accepts an optional remark to be added to the remarks array,
 always return the current remarks array.
 
+Information about the object that cannot be stated in other attributes. May
+include a URL or email address.
+
 =cut
 
 sub remarks {
@@ -180,6 +261,12 @@ Accessor to the admin_c attribute.
 Accepts an optional contact to be added to the admin_c array,
 always return the current admin_c array.
 
+The NIC-handle of an on-site contact 'person' object. As more than one person
+often fulfills a role function, there may be more than one admin_c listed.
+
+An administrative contact (admin_c) must be someone who is physically
+located at the site of the network.
+
 =cut
 
 sub admin_c {
@@ -194,6 +281,14 @@ Accessor to the tech_c attribute.
 Accepts an optional contact to be added to the tech_c array,
 always return the current tech_c array.
 
+The NIC-handle of a technical contact 'person' or 'role' object.  As more than
+one person often fulfills a role function, there may be more than one tech_c
+listed.
+
+A technical contact (tech_c) must be a person responsible for the
+day-to-day operation of the network, but does not need to be
+physically located at the site of the network.
+
 =cut
 
 sub tech_c {
@@ -202,34 +297,6 @@ sub tech_c {
     return \@{ $self->{tech_c} };
 }
 
-=head2 B<cross_mnt( [$mnt] )>
-
-Accessor to the cross_mnt attribute.
-Accepts an optional mnt to be added to the cross_mnt array,
-always return the current cross_mnt array.
-
-=cut
-
-sub cross_mnt {
-    my ( $self, $cross_mnt ) = @_;
-    push @{ $self->{cross_mnt} }, $mnt if defined $mnt;
-    return \@{ $self->{cross_mnt} };
-}
-
-=head2 B<cross_nfy( [$notify] )>
-
-Accessor to the cross_nfy attribute.
-Accepts an optional notify to be added to the cross_nfy array,
-always return the current cross_nfy array.
-
-=cut
-
-sub cross_nfy {
-    my ( $self, $notify ) = @_;
-    push @{ $self->{cross_nfy} }, $notify if defined $notify;
-    return \@{ $self->{cross_nfy} };
-}
-
 =head2 B<notify( [$notify] )>
 
 Accessor to the notify attribute.
@@ -300,39 +367,13 @@ sub changed {
     return \@{ $self->{changed} };
 }
 
-=head2 B<mp_import( [$mp_import] )>
-
-Accessor to the mp_import attribute.
-Accepts an optional mp_import line to be added to the mp_import array,
-always return the current mp_import array.
-
-=cut
-
-sub mp_import {
-    my ( $self, $mp_import ) = @_;
-    push @{ $self->{mp_import} }, $mp_import if defined $mp_import;
-    return \@{ $self->{mp_import} };
-}
-
-=head2 B<mp_export( [$mp_export] )>
-
-Accessor to the mp_export attribute.
-Accepts an optional mp_export line to be added to the mp_export array,
-always return the current mp_export array.
-
-=cut
-
-sub mp_export {
-    my ( $self, $mp_export ) = @_;
-    push @{ $self->{mp_export} }, $mp_export if defined $mp_export;
-    return \@{ $self->{mp_export} };
-}
-
 =head2 B<source( [$source] )>
 
 Accessor to the source attribute.
 Accepts an optional source, always return the current source.
 
+The database where the object is registered.
+
 =cut
 
 sub source {
@@ -346,6 +387,9 @@ sub source {
 Accessor to the org attribute.
 Accepts an optional org, always return the current org.
 
+Only a single value for the org attribute is allowed in the aut-num object.
+This is to ensure only one organisation is responsible for this resource.
+
 =cut
 
 sub org {
